servlib/bundling/FragmentManager.cc
changeset 37 6023dbd1cef5
parent 36 25401075f22b
--- a/servlib/bundling/FragmentManager.cc	Mon Aug 15 12:35:59 2011 +0100
+++ b/servlib/bundling/FragmentManager.cc	Mon Aug 15 13:42:11 2011 +0100
@@ -434,14 +434,16 @@
                    fragment->frag_offset());
 
 
     // XXX/lynch ensure that non-payload blocks are added to fragment bundle
     // but only add one block of each type
     BlockInfoVec::const_iterator block_i;
     for (block_i =  fragment->recv_blocks().begin();
          block_i != fragment->recv_blocks().end(); 
          ++block_i)
     {
         if ( !state->bundle()->recv_blocks().has_block( block_i->type() ) &&
+             block_i->type() != BundleProtocol::PRIMARY_BLOCK             && 
              block_i->type() != BundleProtocol::PAYLOAD_BLOCK ) {
 
             log_debug("Adding block(%d) to fragment bundle", block_i->type());
@@ -434,14 +434,16 @@
 
 
-    // XXX/lynch ensure that non-payload blocks are added to fragment bundle
-    // but only add one block of each type
+    // XXX/lynch ensure that extension blocks are added to the assembled bundle
+    // Only add each block type once
+    // And don't add primary / payload blocks (this is done elsewhere)
     BlockInfoVec::const_iterator block_i;
     for (block_i =  fragment->recv_blocks().begin();